# Device Mockups

Screen and device frame clips for wrapping content inside browser,
phone, or desktop window chrome.

## BrowserMockup

::: pymotion.clip.mockup.BrowserMockup

## PhoneMockup

::: pymotion.clip.mockup.PhoneMockup

## DesktopMockup

::: pymotion.clip.mockup.DesktopMockup
